/*
 * DemosceneMusic - AudioCodecFilter.java - Copyright © 2012 David Roden
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.pterodactylus.demoscenemusic.utils;

import java.util.HashMap;
import java.util.Map;

/**
 * Helper for audio codec descriptions.
 *
 * @author <a href="mailto:bombe@pterodactylus.net">David ‘Bombe’ Roden</a>
 */
public class AudioCodecs {

	/** Descriptions for audio codecs. */
	public static final Map<String, AudioCodecDescription> codecDescriptions = new HashMap<String, AudioCodecDescription>();

	static {
		codecDescriptions.put("mp3", new AudioCodecDescription("mp3", "MPEG 1 Layer 3", "MP3", "audio/mpeg", true, false));
		codecDescriptions.put("vorbis", new AudioCodecDescription("vorbis", "Ogg Vorbis", "Vorbis", "audio/vorbis", true, false));
		codecDescriptions.put("aac", new AudioCodecDescription("aac", "Advanced Audio Coding", "AAC", "audio/x-aac", true, false));
		codecDescriptions.put("flac", new AudioCodecDescription("flac", "Free Lossless Audio Codec", "FLAC", "audio/ogg", true, true));
		codecDescriptions.put("wav", new AudioCodecDescription("wav", "Waveform Audio", "WAV", "audio/vnc.wave", true, true));
		codecDescriptions.put("mod", new AudioCodecDescription("mod", "Module", "MOD", "audio/mod", false, true));
		codecDescriptions.put("ft2", new AudioCodecDescription("ft2", "FastTracker II Module", "XM", "audio/xm", false, true));
	}

	/**
	 * Bundles descriptions for various audio codecs. For simplicity reasons,
	 * file formats such as MOD, IT, or SID are also treated as audio codecs
	 * even though they are not.
	 *
	 * @author <a href="mailto:bombe@pterodactylus.net">David ‘Bombe’ Roden</a>
	 */
	public final static class AudioCodecDescription {

		/** The code of this codec. */
		public final String code;

		/** The full name of the codec. */
		public final String name;

		/** The short name of the codec. */
		public final String shortName;

		/** The MIME type. */
		public final String mimeType;

		/** Whether this is a streaming codec. */
		public final boolean streaming;

		/** Whether this codec is lossless. */
		public final boolean lossless;

		/**
		 * Creates a new audio codec description.
		 *
		 * @param code
		 *            The code of the codec
		 * @param name
		 *            The full name of the codec
		 * @param shortName
		 *            The short name of the codec
		 * @param mimeType
		 *            The MIME type of the audio codec
		 * @param streaming
		 *            {@code true} if the codec is a streaming audio codec,
		 *            {@code false} otherwise
		 * @param lossless
		 *            {@code true} if the codec is a lossless audio codec,
		 *            {@code false} otherwise
		 */
		AudioCodecDescription(String code, String name, String shortName, String mimeType, boolean streaming, boolean lossless) {
			this.code = code;
			this.name = name;
			this.shortName = shortName;
			this.mimeType = mimeType;
			this.streaming = streaming;
			this.lossless = lossless;
		}

	}

}
